Class: ActionView::VueTagHelper::Railtie

Inherits:
Rails::Railtie
  • Object
show all
Defined in:
lib/actionview/vue_tag_helper/railtie.rb

Overview

Integrates the vue view helper into Rails applications.

When Rails is present this Railtie is required automatically and the helper is included into ActionView::Base via the :action_view load hook, which is the correct integration point for ActionView extensions.